Changelog
=========


1.1.3 (2019-03-19)
------------------

- Add ScalesPurgePaths adapter to purge dexterity images and files.
  [bsuttor]


1.1.2 (2019-03-18)
------------------

- Add explicit error if error during domain parsing
  [jfroche]

- Fix method to verify if we are using minisite
  [jfroche]


1.1.1 (2019-03-18)
------------------

- Add upgrade step to enable virtualHosting.
  [bsuttor]


1.1 (2019-03-18)
----------------

- Always enable caching with virtualhosting.
  [jfrcohe]

- Empty cachingProxies registry value. This value is get by environment variable.
  [bsuttor]


1.0 (2016-05-18)
----------------

- Initial release.
  [jfroche]
